@@ -27,7 +27,8 @@ namespace Model
   {
     NOT_SET,
     certificate_authentication,
-    directory_service_authentication
+    directory_service_authentication,
+    federated_authentication
   };
 
 namespace ClientVpnAuthenticationTypeMapper
